import { forwardRef, useRef } from 'react';
import PropTypes from 'prop-types';
import { toQueryString } from '@s-ui/js/lib/string';
import useImperativeApi from '../hooks/useImperativeApi.js';
import useTimeLimitCheck from '../hooks/vimeo/useTimeLimitCheck.js';
import useVideoMetadata from '../hooks/vimeo/useVideoMetadata.js';
import useVimeoApi from '../hooks/vimeo/useVimeoApi.js';
import useVimeoProperties from '../hooks/vimeo/useVimeoProperties.js';
import { BASE_CLASS, VIMEO_DEFAULT_TITLE } from '../settings/index.js';
import { jsx as _jsx } from "react/jsx-runtime";
var VimeoPlayer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    muted = _ref.muted,
    onLoadVideo = _ref.onLoadVideo,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    src = _ref.src,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? VIMEO_DEFAULT_TITLE : _ref$title;
  var _useVimeoProperties = useVimeoProperties(),
    getEmbeddableUrl = _useVimeoProperties.getEmbeddableUrl;
  var params = toQueryString({
    autoplay: autoPlay ? '1' : '0',
    controls: controls ? '1' : '0',
    muted: muted ? '1' : '0'
  });
  var time = "#t=" + timeOffset;
  var videoSrc = getEmbeddableUrl(src) + "?" + params + time;
  var playerRef = useRef(null);
  var vimeoPlayer = useRef(null);
  var _useTimeLimitCheck = useTimeLimitCheck({
      playerRef: playerRef,
      timeLimit: timeLimit,
      timeOffset: timeOffset
    }),
    startTimeLimitInterval = _useTimeLimitCheck.startTimeLimitInterval,
    stopTimeLimitInterval = _useTimeLimitCheck.stopTimeLimitInterval;
  var _useVideoMetadata = useVideoMetadata({
      src: src,
      onLoadVideo: onLoadVideo
    }),
    loadVideoMetadata = _useVideoMetadata.loadVideoMetadata;
  useVimeoApi({
    playerRef: playerRef,
    onPlay: startTimeLimitInterval,
    onPause: stopTimeLimitInterval,
    onLoad: function onLoad(player) {
      vimeoPlayer.current = player.current;
      loadVideoMetadata(player);
    },
    onCleanEffect: stopTimeLimitInterval
  });
  useImperativeApi({
    ref: forwardedRef,
    getCurrentTime: function getCurrentTime() {
      return vimeoPlayer.current.getCurrentTime();
    }
  });
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-vimeoPlayer",
    children: /*#__PURE__*/_jsx("iframe", {
      className: BASE_CLASS + "-vimeoPlayerFrame",
      title: title,
      src: videoSrc,
      frameBorder: "0",
      allow: "autoplay; fullscreen; picture-in-picture",
      allowFullScreen: true,
      ref: playerRef
    })
  });
});
export default VimeoPlayer;