import { forwardRef, useEffect } from 'react';
import PropTypes from 'prop-types';
import { toQueryString } from '@s-ui/js/lib/string';
import useImperativeApi from '../hooks/useImperativeApi.js';
import useYouTubeProperties from '../hooks/youtube/useYouTubeProperties.js';
import { BASE_CLASS, YOUTUBE_DEFAULT_TITLE } from '../settings/index.js';
import { YOUTUBE } from '../settings/players.js';
import { jsx as _jsx } from "react/jsx-runtime";
var YouTubePlayer = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var autoPlay = _ref.autoPlay,
    controls = _ref.controls,
    muted = _ref.muted,
    onLoadVideo = _ref.onLoadVideo,
    src = _ref.src,
    timeLimit = _ref.timeLimit,
    timeOffset = _ref.timeOffset,
    _ref$title = _ref.title,
    title = _ref$title === void 0 ? YOUTUBE_DEFAULT_TITLE : _ref$title;
  var _useYouTubeProperties = useYouTubeProperties(),
    getEmbeddableUrl = _useYouTubeProperties.getEmbeddableUrl;
  useEffect(function () {
    onLoadVideo({
      src: src,
      type: YOUTUBE.VIDEO_TYPE,
      duration: null,
      videoWidth: null,
      videoHeight: null
    });
  }, []);
  useImperativeApi({
    ref: forwardedRef,
    getCurrentTime: function getCurrentTime() {
      return Promise.resolve(null);
    }
  });
  var params = toQueryString({
    autoplay: autoPlay ? '1' : '0',
    controls: controls ? '1' : '0',
    start: timeOffset || '0',
    end: timeLimit,
    mute: muted ? '1' : '0'
  });
  var videoSrc = getEmbeddableUrl(src) + "?" + params;
  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS + "-youtubePlayer",
    children: /*#__PURE__*/_jsx("iframe", {
      className: BASE_CLASS + "-youtubePlayerFrame",
      src: videoSrc,
      title: title,
      frameBorder: "0",
      allow: "accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share",
      allowFullScreen: true
    })
  });
});
export default YouTubePlayer;